@@ -122,27 +122,28 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
                         r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
                 elif effect != 1 and effector != None:
                     effector.brightness = brightness
-                mqttclient.publish(MQTT_BASE_TOPIC+"/report/brightness", int(brightness))
             except ValueError:
                 return
+        mqttclient.publish(MQTT_BASE_TOPIC+"/report/brightness", int(brightness))
     elif topic == MQTT_BASE_TOPIC+"/control/color":
-        if effector != None:
-            effector.stop_effect()
-            effector = None
-            effect = 0
-            mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
-                       led_effects.effects[effect]['name'])
-        try:
-            [rtmp,gtmp,btmp] = payload.split(',')
-            r = float(rtmp)
-            g = float(gtmp)
-            b = float(btmp)
-            led.fill_led_with_color(
-                r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
-            mqttclient.publish(MQTT_BASE_TOPIC+"/report/color", str(int(r))+","+str(int(g))+","+str(int(b)))
-        except ValueError:
-            print("Invalid Payload")
-            return
+        if effect != 1:
+            if effector != None:
+                effector.stop_effect()
+                effector = None
+                effect = 0
+                mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
+                        led_effects.effects[effect]['name'])
+            try:
+                [rtmp,gtmp,btmp] = payload.split(',')
+                r = float(rtmp)
+                g = float(gtmp)
+                b = float(btmp)
+                led.fill_led_with_color(
+                    r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
+            except ValueError:
+                print("Invalid Payload")
+                return
+        mqttclient.publish(MQTT_BASE_TOPIC+"/report/color", str(int(r))+","+str(int(g))+","+str(int(b)))
     elif topic == MQTT_BASE_TOPIC+"/control/effect":
         if effector != None:
             effector.stop_effect()
@@ -153,7 +154,9 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
                 if effect == 0:
                     led.fill_led_with_color(
                         r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
-                if effect >= 2 and state:
+                elif effect == 1:
+                    led.turn_off()
+                elif effect >= 2 and state:
                     effector = led_effects.effects[i]['class'](
                         frame_time=0.1, led=led, brightness=brightness)
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
